@@ -77,7 +77,7 @@ template_entry_order = [
 ]
 
 
-@inbranch(BLOOM_CONFIG_BRANCH)
+@inbranch('bloom')
 def convert_old_bloom_conf(prefix=None):
     prefix = prefix if prefix is not None else 'convert'
     tracks_dict = get_tracks_dict_raw()
